import { world, system } from "@minecraft/server";

export function getRandomInt(min, max) {
	return Math.floor(Math.random() * (max - min + 1)) + min;
}

/**
 * Register a tick timeout
 * @param {(data: BeforeChatEvent, args: Array<string>) => void} callback Code you want to execute when the command is executed
 * @param {number} tick time in ticks you want the return to occur
 * @example
 *  SA.TickTimeOutBuild.setTickTimeout(function () {
 *    console.log(`callback`)
 * });
 */
export function setTickTimeout(callback, tick) {
  new tickTimeout(callback, tick);
}
/**
 * Delay executing a function, REPEATEDLY
 * @param {(data: BeforeChatEvent, args: Array<string>) => void} callback Code you want to execute when the command is executed
 * @param {number} tick time in ticks you want the return to occur
 * @returns {number}
 */
export function setTickInterval(callback, tick) {
  new tickTimeout(callback, tick, true);
}
class tickTimeout {
  /**
   * Register a timeout
   * @param {(data: BeforeChatEvent, args: Array<string>) => void} callback Code you want to execute when the command is executed
   * @param {number} time time in Date want the function to run
   */
  constructor(callback, tick, loop = false) {

    let tickDelay = tick;
    let callbackTick = 0;
    let finish = false

    let syst = [
      system.run(function tick(data) {
        if (finish === true) return 
        system.run(tick)
        if (callbackTick == 0) {
          callbackTick = data.currentTick + tickDelay;
        }
        try {
          if (callbackTick <= data.currentTick) {
            // return callback
            try {
              callback();
            } catch (error) {}
            
            if (loop) {
              callbackTick = data.currentTick + tickDelay;
            } else {
              finish = true;
            }
          }
        } catch (error) {
          console.warn(`${error} : ${error.stack}`);
        }
      })
    ]
  }
}

export function dhm(ms) {
  let days = Math.floor(ms / (24 * 60 * 60 * 1000));
  let daysms = ms % (24 * 60 * 60 * 1000);
  let hours = Math.floor((daysms) / (60 * 60 * 1000));
  let hoursms = ms % (60 * 60 * 1000);
  let minutes = Math.floor((hoursms) / (60 * 1000));
  let minutesms = ms % (60 * 1000);
  let sec = Math.floor((minutesms) / (1000));
  return [days, hours, minutes, sec]
}

export function removeItemOnce(arr, value) {
  var index = arr.indexOf(value);
  if (index > -1) {
    arr.splice(index, 1);
  }
  return arr;
}