import { world, system } from '@minecraft/server';

import { getColor, getConfig } from './Chat/NameMessageColor/NameMessageColor.js';

import { getRank } from './Chat/getRank/getRank.js';

import { NAMETAG_COLOR_PREFIX } from './Chat/NameMessageColor/Config/NameColorConfig.js';

import { CHAT_COLOR_PREFIX } from './Chat/NameMessageColor/Config/MessageColorConfig.js';

import './Chat/CoolDown/cooldown.js';
import { getFormatedCooldown, handleCooldown } from './Chat/CoolDown/cooldown.js';

import Config from './Chat/Config.js'

world.beforeEvents.chatSend.subscribe((data) => {
	data.cancel = true;
	let player = data.sender;

	// Test if player is muted
	if (player.hasTag('mute')) {
		player.sendMessage(`§7[§r§3Chat§bColors§7]§r §3You are muted!`); // Send mute chat message
	} else {
		if (!handleCooldown(player.id))
			return player.sendMessage(`§7[§r§3Chat§bColors§7]§r §cDon't spam the chat, please wait ${getFormatedCooldown(player.id)}s`);
		if (Config.MAX_CHAR_PER_MESSAGE !== null && data.message?.length > Config.MAX_CHAR_PER_MESSAGE)
			return player.sendMessage(`§7[§r§3Chat§bColors§7]§r §cYou are not able to send message within more than ${Config.MAX_CHAR_PER_MESSAGE} characters`);
		world.sendMessage(
			'§r' +
				getConfig(player, 'dimension') +
				'§7[§f' +
				getRank(player) +
				'§7] ' +
				getColor(player, NAMETAG_COLOR_PREFIX, player.name) +
				'§7§l > §r' +
				getColor(player, CHAT_COLOR_PREFIX, data.message.replaceAll('§', ''))
		);
	}
});

// Apply ranks and colors in Player NameTag
system.runInterval(() => {
	for (const player of world.getPlayers()) {
		// Set Player NameTag
		player.nameTag =
			'§r' +
			getConfig(player, 'dimension') +
			'§7[§f' +
			getRank(player) +
			'§7]§r ' +
			getColor(player, NAMETAG_COLOR_PREFIX, player.name) +
			'§r' +
			getConfig(player, 'health');
	}
});
