import { DEFAULT_NAMETAG_COLOR, NAMETAG_COLOR_PREFIX } from './Config/NameColorConfig.js';
import { DEFAULT_CHAT_COLOR, CHAT_COLOR_PREFIX } from './Config/MessageColorConfig.js';
import { CONFIGTAG } from './Config/ConfigTag.js';
import { COLORS } from '../Colors/ColorsConstant.js';

import CustomText from '../Class/CustomTextClass.js';

export function getColor(player, tagseparator, message) {
	const chatColorTag = player
		.getTags()
		.find((tag) => tag.startsWith(tagseparator) && !tag.endsWith('bold') && !tag.endsWith('italic') && !tag.endsWith('glitch'));

	let Symbols = [];

	if (player.hasTag(tagseparator + 'glitch') || player.hasTag(tagseparator + '§k')) Symbols.push(`§k`);

	if (player.hasTag(tagseparator + 'bold') || player.hasTag(tagseparator + '§l')) Symbols.push(`§l`);

	if (player.hasTag(tagseparator + 'italic') || player.hasTag(tagseparator + '§o')) Symbols.push(`§o`);

	const otherSymbols = Symbols.join('');

	if (!chatColorTag) {
		switch (tagseparator) {
			case NAMETAG_COLOR_PREFIX:
				return otherSymbols + DEFAULT_NAMETAG_COLOR + message;
			case CHAT_COLOR_PREFIX:
				return otherSymbols + DEFAULT_CHAT_COLOR + message;
		}
	}

	switch (chatColorTag.replace(tagseparator, '')) {
		case 'black':
			return otherSymbols + '§0' + message;
			break;

		case 'darkBlue':
			return otherSymbols + '§1' + message;
			break;

		case 'darkGreen':
			return otherSymbols + '§2' + message;
			break;

		case 'darkAqua':
			return otherSymbols + '§3' + message;
			break;

		case 'darkRed':
			return otherSymbols + '§4' + message;
			break;

		case 'darkPurple':
			return otherSymbols + '§5' + message;
			break;

		case 'gold':
			return otherSymbols + '§6' + message;
			break;

		case 'gray':
			return otherSymbols + '§7' + message;
			break;

		case 'darkGray':
			return otherSymbols + '§8' + message;
			break;

		case 'blue':
			return otherSymbols + '§9' + message;
			break;

		case 'green':
			return otherSymbols + '§a' + message;
			break;

		case 'aqua':
			return otherSymbols + '§b' + message;
			break;

		case 'red':
			return otherSymbols + '§c' + message;
			break;

		case 'lightPurple':
			return otherSymbols + '§d' + message;
			break;

		case 'yellow':
			return otherSymbols + '§e' + message;
			break;

		case 'white':
			return otherSymbols + '§f' + message;
			break;

		case 'minecoinGold':
			return otherSymbols + '§g' + message;

		case 'blueDarkGrey':
			return otherSymbols + '§t' + message;

		case 'mediumPurple':
			return otherSymbols + '§u' + message;

		case 'darkOrange':
			return otherSymbols + '§p' + message;

		case 'mediumGreen':
			return otherSymbols + '§q' + message;

		case 'mediumCyan':
			return otherSymbols + '§s' + message;

		case 'beige':
			return otherSymbols + '§h' + message;

		case 'darkBrown':
			return otherSymbols + '§j' + message;

		case 'mediumRed':
			return otherSymbols + '§m' + message;

		case 'brown':
			return otherSymbols + '§n' + message;

			break;

		// Raimbow
		case 'randomRaimbow':
			return otherSymbols + new CustomText(message).setRaimbow(true);
			break;

		case 'raimbow':
			return otherSymbols + new CustomText(message).setRaimbow();
			break;

		// Blue Gradients
		case 'blueGradient':
			return otherSymbols + new CustomText(message).setGradient('blue');
			break;

		case 'randomBlueGradient':
			return otherSymbols + new CustomText(message).setGradient('blue', true);
			break;

		// Yellow Gradients
		case 'yellowGradient':
			return otherSymbols + new CustomText(message).setGradient('yellow');
			break;

		case 'randomYellowGradient':
			return otherSymbols + new CustomText(message).setGradient('yellow', true);
			break;

		// Black Gradients
		case 'blackGradient':
			return otherSymbols + new CustomText(message).setGradient('black');
			break;

		case 'randomBlackGradient':
			return otherSymbols + new CustomText(message).setGradient('black', true);
			break;

		// Gray Gradients
		case 'grayGradient':
			return otherSymbols + new CustomText(message).setGradient('gray');
			break;

		case 'randomGrayGradient':
			return otherSymbols + new CustomText(message).setGradient('gray', true);
			break;

		// Gray Gradients
		case 'purpleGradient':
			return otherSymbols + new CustomText(message).setGradient('purple');
			break;

		case 'randomPurpleGradient':
			return otherSymbols + new CustomText(message).setGradient('purple', true);
			break;

		default:
			if (COLORS.includes(chatColorTag.replace(tagseparator, ''))) {
				let index = chatColorTag.replace(tagseparator, '').indexOf('§');
				return otherSymbols + chatColorTag.replace(tagseparator, '')[index] + chatColorTag.replace(tagseparator, '')[index + 1] + message;
			} else {
				switch (tagseparator) {
					case NAMETAG_COLOR_PREFIX:
						return otherSymbols + DEFAULT_NAMETAG_COLOR + message;
					case CHAT_COLOR_PREFIX:
						return otherSymbols + DEFAULT_CHAT_COLOR + message;
				}
			}
			break;
	}
}

export function getDimension(player) {
	switch (player.dimension.id) {
		case 'minecraft:overworld':
			return '§r§7<§f§aOverWorld§7> §r';
			break;

		case 'minecraft:nether':
			return '§r§7<§f§4Nether§7> §r';
			break;

		case 'minecraft:the_end':
			return '§r§7<§f§dEnder§7> §r';
			break;
	}
}

export function getConfig(player, type = null) {
	switch (type) {
		case 'dimension':
			if (player.hasTag(CONFIGTAG + 'dimension')) return getDimension(player);
			else return '';

		case 'health':
			if (player.hasTag(CONFIGTAG + 'health'))
				return `\n§c${Math.round(player.getComponent('health').currentValue * 10) / 10}§4/§c${player.getComponent('health').effectiveMax}`;
			else return '';

		default:
			return '';
	}
}
